*******************
External extensions
*******************

Here you can find a list of external packages that extend Mopidy with
additional functionality. This list is moderated and updated on a regular
basis. If you want your package to show up here, follow the :ref:`guide on
creating extensions <extensiondev>`.

Mopidy also bundles some extensions:

- :ref:`ext-local`
- :ref:`ext-stream`
- :ref:`ext-http`
- :ref:`ext-mpd`


Mopidy-Arcam
============

https://github.com/TooDizzy/mopidy-arcam

Extension for controlling volume using an external Arcam amplifier. Developed
and tested with an Arcam AVR-300.


Mopidy-Beets
============

https://github.com/mopidy/mopidy-beets

Provides a backend for playing music from your `Beets
<http://beets.radbox.org/>`_ music library through Beets' web extension.


Mopidy-Dirble
=============

https://github.com/mopidy/mopidy-dirble

Provides a backend for browsing the Internet radio channels from the `Dirble
<http://dirble.com/>`_ directory.


Mopidy-GMusic
=============

https://github.com/hechtus/mopidy-gmusic

Provides a backend for playing music from `Google Play Music
<https://play.google.com/music/>`_.


Mopidy-MPRIS
============

https://github.com/mopidy/mopidy-mpris

Extension for controlling Mopidy through the `MPRIS <http://www.mpris.org/>`_
D-Bus interface, for example using the Ubuntu Sound Menu.


Mopidy-NAD
==========

https://github.com/mopidy/mopidy-nad

Extension for controlling volume using an external NAD amplifier.


Mopidy-Notifier
===============

https://github.com/sauberfred/mopidy-notifier

Extension for displaying track info as User Notifications in Mac OS X.


Mopidy-radio-de
===============

https://github.com/hechtus/mopidy-radio-de

Extension for listening to Internet radio stations and podcasts listed at
`radio.de <http://www.radio.de/>`_, `rad.io <http://www.rad.io/>`_,
`radio.fr <http://www.radio.fr/>`_, and `radio.at <http://www.radio.at/>`_.


Mopidy-Scrobbler
================

https://github.com/mopidy/mopidy-scrobbler

Extension for scrobbling played tracks to Last.fm.


Mopidy-SomaFM
=============

https://github.com/AlexandrePTJ/mopidy-somafm

Provides a backend for playing music from the `SomaFM <http://somafm.com/>`_
service.


Mopidy-SoundCloud
=================

https://github.com/mopidy/mopidy-soundcloud

Provides a backend for playing music from the `SoundCloud
<http://www.soundcloud.com/>`_ service.


Mopidy-Spotify
==============

https://github.com/mopidy/mopidy-spotify

Extension for playing music from the `Spotify <http://www.spotify.com/>`_ music
streaming service.


Mopidy-Subsonic
===============

https://github.com/rattboi/mopidy-subsonic

Provides a backend for playing music from a `Subsonic Music Streamer
<http://www.subsonic.org/>`_ library.


Mopidy-VKontakte
================

https://github.com/sibuser/mopidy-vkontakte

Provides a backend for playing music from the `VKontakte social network
<http://vk.com/>`_.
